@@ -116,6 +116,7 @@ struct _MetaScreen
 #endif
 
   Window wm_cm_selection_window;
+  guint32 wm_cm_timestamp;
 
   guint work_area_later;
 
@@ -129,9 +130,6 @@ struct _MetaScreen
   
   int closing;
 
-  /* gc for XOR on root window */
-  GC root_xor_gc;
-
   /* Managed by compositor.c */
   gpointer compositor_data;
   
